# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'bar.ui'
#
# Created by: PyQt5 UI code generator 5.15.1
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_BarDisplay(object):
    def setupUi(self, BarDisplay):
        BarDisplay.setObjectName("BarDisplay")
        BarDisplay.resize(480, 666)
        self.verticalLayout = QtWidgets.QVBoxLayout(BarDisplay)
        self.verticalLayout.setObjectName("verticalLayout")
        self.channels = MinimalListWidget(BarDisplay)
        self.channels.setObjectName("channels")
        self.verticalLayout.addWidget(self.channels)
        self.horizontalLayout = QtWidgets.QHBoxLayout()
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label = QtWidgets.QLabel(BarDisplay)
        self.label.setObjectName("label")
        self.horizontalLayout.addWidget(self.label)
        self.timestamp = QtWidgets.QDoubleSpinBox(BarDisplay)
        self.timestamp.setDecimals(9)
        self.timestamp.setSingleStep(0.001)
        self.timestamp.setObjectName("timestamp")
        self.horizontalLayout.addWidget(self.timestamp)
        self.verticalLayout.addLayout(self.horizontalLayout)
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout()
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.min_t = QtWidgets.QLabel(BarDisplay)
        self.min_t.setText("")
        self.min_t.setObjectName("min_t")
        self.horizontalLayout_2.addWidget(self.min_t)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_2.addItem(spacerItem)
        self.max_t = QtWidgets.QLabel(BarDisplay)
        self.max_t.setText("")
        self.max_t.setObjectName("max_t")
        self.horizontalLayout_2.addWidget(self.max_t)
        self.verticalLayout.addLayout(self.horizontalLayout_2)
        self.timestamp_slider = QtWidgets.QSlider(BarDisplay)
        self.timestamp_slider.setMaximum(9999)
        self.timestamp_slider.setOrientation(QtCore.Qt.Horizontal)
        self.timestamp_slider.setInvertedAppearance(False)
        self.timestamp_slider.setInvertedControls(False)
        self.timestamp_slider.setTickPosition(QtWidgets.QSlider.NoTicks)
        self.timestamp_slider.setTickInterval(1)
        self.timestamp_slider.setObjectName("timestamp_slider")
        self.verticalLayout.addWidget(self.timestamp_slider)

        self.retranslateUi(BarDisplay)
        QtCore.QMetaObject.connectSlotsByName(BarDisplay)
        BarDisplay.setTabOrder(self.timestamp, self.timestamp_slider)

    def retranslateUi(self, BarDisplay):
        _translate = QtCore.QCoreApplication.translate
        BarDisplay.setWindowTitle(_translate("BarDisplay", "Form"))
        self.label.setText(_translate("BarDisplay", "Time"))
        self.timestamp.setSuffix(_translate("BarDisplay", "s"))
from asammdf.gui.widgets.list import MinimalListWidget
from . import resource_rc
